@@ -11,6 +11,7 @@ from AccessControl import Unauthorized
 from Products.CMFPlone.utils import base_hasattr
 from Products.CMFPlone.utils import safe_unicode
 from Products.Five import BrowserView
+from appy.pod.renderer import CsvOptions
 from appy.pod.renderer import Renderer
 from appy.pod.styles_manager import TableProperties
 from collective.documentgenerator import config
@@ -254,6 +255,12 @@ class DocumentGenerationView(BrowserView):
         #                       'para[class=indentation,parent=cell]': 'cellIndentation',
         #                       })
 
+        csvOptions = None
+
+        if output_format == "csv":
+            csvOptions = CsvOptions(fieldSeparator=pod_template.csv_field_delimiter,
+                                    textDelimiter=pod_template.csv_string_delimiter)
+
         renderer = Renderer(
             StringIO(document_template.data),
             generation_context,
@@ -268,6 +275,7 @@ class DocumentGenerationView(BrowserView):
             distributeColumns=distributeColumns,
             stylesMapping=stylesMapping,
             stream=config.get_use_stream(),
+            csvOptions=csvOptions,
             **kwargs
         )
 
@@ -372,7 +380,8 @@ class PersistentDocumentGenerationView(DocumentGenerationView):
     Persistent document generation view.
     """
 
-    def __call__(self, template_uid='', output_format=''):
+    def __call__(self, template_uid='', output_format='', generated_doc_title=''):
+        self.generated_doc_title = generated_doc_title
         self.pod_template, self.output_format = self._get_base_args(template_uid, output_format)
         persisted_doc = self.generate_persistent_doc(self.pod_template, self.output_format)
         self.redirects(persisted_doc)
@@ -388,7 +397,7 @@ class PersistentDocumentGenerationView(DocumentGenerationView):
 
     def _get_title(self, doc_name, gen_context):
         splitted_name = doc_name.split('.')
-        title = self.pod_template.title
+        title = self.generated_doc_title or self.pod_template.title
         extension = splitted_name[-1]
         return safe_unicode(title), extension
 
@@ -454,7 +463,8 @@ class MailingLoopPersistentDocumentGenerationView(PersistentDocumentGenerationVi
         This view use a MailingLoopTemplate to loop on a document when replacing some variables in.
     """
 
-    def __call__(self, document_uid='', document_url_path=''):
+    def __call__(self, document_uid='', document_url_path='', generated_doc_title=''):
+        self.generated_doc_title = generated_doc_title
         document_uid = document_uid or self.request.get('document_uid', '')
         document_url_path = document_url_path or self.request.get('document_url_path', '')
         if not document_uid and not document_url_path:
