@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from collective.documentgenerator.config import HAS_PLONE_5_1
+from collective.documentgenerator.config import HAS_PLONE_5_1, HAS_PLONE_4
 from collective.documentgenerator.testing import DexterityIntegrationTests
 from plone import api
 from plone.app.testing import login
@@ -70,6 +70,8 @@ class TestDexterityHelperViewMethods(DexterityIntegrationTests):
         super(TestDexterityHelperViewMethods, self).setUp()
         self.view = self.content.unrestrictedTraverse(
             '@@document_generation_helper_view')
+        self.doc_view = self.doc.unrestrictedTraverse(
+            '@@document_generation_helper_view')
 
     def test_display_method_on_text_field(self):
         field_name = 'fullname'
@@ -107,6 +109,21 @@ class TestDexterityHelperViewMethods(DexterityIntegrationTests):
         msg = "empty value display was expected to be 'foobar'"
         self.assertTrue(displayed == 'foobar', msg)
 
+        displayed = self.doc_view.display('text', no_value='yolo')
+
+        # in plone 4 DX, the attr doesn't exist before manually set but it's None with plone > 5.0
+        if HAS_PLONE_4:
+            self.assertFalse(hasattr(self.doc, 'text'))
+        else:
+            self.assertIsNone(self.doc.text)
+
+        self.assertTrue(displayed == 'yolo', msg)
+
+        self.doc.text = RichTextValue()
+        displayed = self.doc_view.display('text', no_value='yolo')
+        self.assertEqual('', self.doc_view.real_context.text.output)
+        self.assertTrue(displayed == 'yolo', msg)
+
     def test_display_method_bypass_check_permission(self):
         self.content.amount = 20
         self.assertFalse(api.user.is_anonymous())
