@@ -189,6 +189,13 @@ class TestGenerationViewMethods(PODTemplateIntegrationTest):
             filename,
             u'General template.odt')
         self.assertEqual(content_type, 'application/vnd.oasis.opendocument.text')
+        self.assertEqual(persistent_doc.Title(), pod_template.Title())
+
+        # customize the title
+        custom_title = 'my awesome title'
+        generation_view(template_uid=template_uid, output_format='odt', generated_doc_title=custom_title)
+        docgen_file = generation_context.objectValues()[1]
+        self.assertEqual(docgen_file.Title(), custom_title)
 
     def test_persistent_document_generation_on_non_folderish_context(self):
         """
@@ -427,8 +434,8 @@ class TestGenerationViewMethods(PODTemplateIntegrationTest):
         def assert_result(ocw_in_xml, dc_in_xml):
             generated_doc = generation_view(template_uid, 'odt')
             content_xml = self.get_odt_content_xml(generated_doc)
-            self.assertEquals(ocw_in_xml, 'OCW' in content_xml)
-            self.assertEquals(dc_in_xml, 'DC' in content_xml)
+            self.assertEquals(ocw_in_xml, 'OCW' in content_xml, 'OCW not in content_xml')
+            self.assertEquals(dc_in_xml, 'DC' in content_xml, 'DC not in content_xml')
 
         # By default : column_modifier disabled globally, CSS override enabled globally
         # and pod_template using global parameter
